# -*- coding: utf-8 -*-
"""
Created on Wed Jun 16 15:50:02 2021

Who would be so cruel to someone like you?
No one but you
Who would make the rules for the things that you do?
No one but you
I woke up this morning, looked at the sky
I thought of all of the time passing by
It didn't matter how hard we tried
'Cause in the end

@author: KING
"""

print('哈哈哈哈哈宝宝')